@@ -37,6 +37,21 @@
 #     interval:       how often to log frequent keys [ms, default: 0]
 #     percent:        percentage of frequent keys to log [%, default: 100]
 #     log:            location of log file for frequent keys [default: STDOUT]
+#   deleteIdleStats:  don't send values to graphite for inactive counters, sets,
+#                     gauges, or timers as opposed to sending 0. For gauges,
+#                     this unsets the gauge (instead of sending the previous value).
+#                     Can be indivdually overriden. [default: false]
+#   deleteGauges:     don't send values to graphite for inactive gauges, as opposed
+#                     to sending the previous value [default: false]
+#   deleteTimers:     don't send values to graphite for inactive timers, as opposed
+#                     to sending 0 [default: false]
+#   deleteSets:       don't send values to graphite for inactive sets, as opposed
+#                     to sending 0 [default: false]
+#   deleteCounters:   don't send values to graphite for inactive counters, as opposed
+#                     to sending 0 [default: false]
+#   prefixStats:      prefix to use for the statsd statistics data for this running
+#                     instance of statsd [default: statsd]
+#                     applies to both legacy and new namespacing
 #   deleteCounters:   don't send values to graphite for inactive counters,
 #                     as opposed to sending 0 [default: false]
 #
@@ -88,7 +103,8 @@
   },
 
   # Available backends are: Graphite, Console, File
-  "backends": [ "Graphite", "Console" ],
+  #"backends": [ "Graphite", "Console" ],
+  "backends": [ "Console", "ElasticSearch" ],
 
   # File backend config example
   #"file" : {
@@ -101,6 +117,8 @@
   #  "log" : "/var/tmp/statsd-top.log",
   #},
 
+  "deleteIdleStats" : true,
+
   # statsd will periodically flush its metrics to Graphite
   # Be sure to include the Graphite backend above
   "graphitePort": 2003,
@@ -109,6 +127,16 @@
     "legacyNamespace" : false
   },
 
+  "elasticsearch" : {
+    "host" : "10.20.57.30",
+    "port" : 9200,
+    "path" : "/",
+    "indexPrefix" : "vstatd",
+    "countType" : "vstatd",
+    "timerType" : "vstatd",
+    "timerDataType" : "vstatd",
+  },
+
   ## Repeater backend is not implemented yet
   #"repeater": [ { "host": "10.1.2.3", "port": 8125 } ],
   #"repeaterProtocol": "udp4"
